"""
alphabeta - A/B testing tools.
"""

# Author: Trevor Stephens <trevorstephens.com>
#
# License: BSD 3 clause

import math
from scipy.stats import norm

__all__ = ['power_prop_test']


def power_prop_test(p1, p2, power=0.8, significance=0.05, tside=2, k=1.0):
    # Bernard Rosner - Fundamentals of Biostatistics.
    # Where n2 is k times as large as n1
    # Returns required sample size in *each* group
    q1, q2 = 1. - p1, 1. - p2
    p_bar = (p1 + (k * p2)) / (1. + k)
    q_bar = 1. - p_bar
    delta = abs(p2 - p1)
    z_alpha = norm.isf(1 - (significance / tside))
    z_beta = norm.isf(power) # power = 1 - beta
    lhs = math.sqrt(p_bar * q_bar * (1. + (1. / k))) * z_alpha
    rhs = math.sqrt(p1 * q1 + (p2 * q2 / k)) * z_beta
    n = ((lhs + rhs) ** 2) / delta ** 2
    if k == 1:
        return math.ceil(n)
    return math.ceil(n), math.ceil(k * n)



#! /usr/bin/env python

"""alphabeta - A/B testing tools."""

from setuptools import setup, find_packages
import alphabeta

DESCRIPTION = __doc__
VERSION = alphabeta.__version__

setup(name='alphabeta',
      version=VERSION,
      description=DESCRIPTION,
      long_description=open("README.rst").read(),
      classifiers=['Development Status :: 3 - Alpha',
                   'Intended Audience :: Science/Research',
                   'Intended Audience :: Developers',
                   'License :: OSI Approved',
                   'Topic :: Software Development',
                   'Topic :: Scientific/Engineering',
                   'Operating System :: Microsoft :: Windows',
                   'Operating System :: Unix',
                   'Operating System :: MacOS',
                   'Programming Language :: Python',
                   'Programming Language :: Python :: 3',
                   'Programming Language :: Python :: 3.8',
                   'Programming Language :: Python :: 3.9',
                   'Programming Language :: Python :: 3.10'],
      author='Trevor Stephens',
      author_email='trev.stephens@gmail.com',
      url='https://github.com/trevorstephens/alphabeta',
      license='new BSD',
      packages=find_packages(exclude=['*.tests',
                                      '*.tests.*']),
      zip_safe=False,
      package_data={'': ['LICENSE']},
      install_requires=['scipy'])
